@@ -50,6 +50,9 @@ ReportGenerator::ReportGenerator(DataStore *db)
     // Enable searching for included templates in files if we have a template directory
     m_injaEnv.set_search_included_templates_in_files(!m_conf->templateDir().empty());
 
+    // escape HTML automatically
+    m_injaEnv.set_html_autoescape(true);
+
     m_htmlExportDir = m_conf->htmlExportDir;
     m_mediaPoolDir = m_dstore->mediaExportPoolDir();
     m_mediaPoolUrl = std::format("{}/pool", m_conf->mediaBaseUrl);
@@ -98,6 +101,7 @@ void ReportGenerator::renderPage(const std::string &pageID, const std::string &e
         defaultEnv = std::make_unique<inja::Environment>(m_defaultTemplateDir.string() + "/");
         // Configure the default environment to search for included templates in files
         defaultEnv->set_search_included_templates_in_files(true);
+        defaultEnv->set_html_autoescape(true);
         activeEnv = defaultEnv.get();
     }
 
@@ -139,8 +143,9 @@ void ReportGenerator::renderPagesFor(const std::string &suiteName, const std::st
 
             inja::json architectures = inja::json::array();
             for (const auto &arch : hentry.archs) {
-                architectures.push_back(inja::json{
-                    {"arch", arch}
+                architectures.push_back(
+                    inja::json{
+                        {"arch", arch}
                 });
             }
             entry["architectures"] = architectures;
@@ -150,9 +155,10 @@ void ReportGenerator::renderPagesFor(const std::string &suiteName, const std::st
                 entry["has_errors"] = true;
                 inja::json errors = inja::json::array();
                 for (const auto &error : hentry.errors) {
-                    errors.push_back(inja::json{
-                        {"error_tag",         error.tag    },
-                        {"error_description", error.message}
+                    errors.push_back(
+                        inja::json{
+                            {"error_tag",         error.tag    },
+                            {"error_description", error.message}
                     });
                 }
                 entry["errors"] = errors;
@@ -163,9 +169,10 @@ void ReportGenerator::renderPagesFor(const std::string &suiteName, const std::st
                 entry["has_warnings"] = true;
                 inja::json warnings = inja::json::array();
                 for (const auto &warning : hentry.warnings) {
-                    warnings.push_back(inja::json{
-                        {"warning_tag",         warning.tag    },
-                        {"warning_description", warning.message}
+                    warnings.push_back(
+                        inja::json{
+                            {"warning_tag",         warning.tag    },
+                            {"warning_description", warning.message}
                     });
                 }
                 entry["warnings"] = warnings;
@@ -176,9 +183,10 @@ void ReportGenerator::renderPagesFor(const std::string &suiteName, const std::st
                 entry["has_infos"] = true;
                 inja::json infos = inja::json::array();
                 for (const auto &info : hentry.infos) {
-                    infos.push_back(inja::json{
-                        {"info_tag",         info.tag    },
-                        {"info_description", info.message}
+                    infos.push_back(
+                        inja::json{
+                            {"info_tag",         info.tag    },
+                            {"info_description", info.message}
                     });
                 }
                 entry["infos"] = infos;
@@ -208,14 +216,13 @@ void ReportGenerator::renderPagesFor(const std::string &suiteName, const std::st
 
                 inja::json architectures = inja::json::array();
                 for (const auto &arch : mentry.archs) {
-                    architectures.push_back(inja::json{
-                        {"arch", arch}
+                    architectures.push_back(
+                        inja::json{
+                            {"arch", arch}
                     });
                 }
                 cpt["architectures"] = architectures;
-                cpt["metadata"] = Utils::escapeXml(
-                    mentry.data); // FIXME: Set html-autoescape in Inja once we can depend on a newer version, and don't
-                                  // use explicit escapeXml() here
+                cpt["metadata"] = mentry.data;
 
                 auto cptMediaPath = m_mediaPoolDir / gcid;
                 auto cptMediaUrl = std::format("{}/{}", m_mediaPoolUrl, gcid);
@@ -318,8 +325,9 @@ void ReportGenerator::renderPagesFor(const std::string &suiteName, const std::st
 
             inja::json components = inja::json::array();
             for (const auto &cid : pkgSummary.cpts) {
-                components.push_back(inja::json{
-                    {"cid", cid}
+                components.push_back(
+                    inja::json{
+                        {"cid", cid}
                 });
             }
             pkg["components"] = components;
@@ -717,8 +725,9 @@ void ReportGenerator::updateIndexPages()
 
     inja::json suitesArray = inja::json::array();
     for (const auto &suite : suites) {
-        suitesArray.push_back(inja::json{
-            {"suite", suite.name}
+        suitesArray.push_back(
+            inja::json{
+                {"suite", suite.name}
         });
 
         inja::json secCtx;
@@ -726,8 +735,9 @@ void ReportGenerator::updateIndexPages()
 
         inja::json sectionsArray = inja::json::array();
         for (const auto &section : suite.sections) {
-            sectionsArray.push_back(inja::json{
-                {"section", section}
+            sectionsArray.push_back(
+                inja::json{
+                    {"section", section}
             });
         }
         secCtx["sections"] = sectionsArray;
