@@ -111,11 +111,12 @@ std::string decompressFile(const std::string &fname)
     int ret = archive_read_open_filename(ar.get(), fname.c_str(), DEFAULT_BLOCK_SIZE);
     if (ret != ARCHIVE_OK) {
         int ret_errno = archive_errno(ar.get());
-        throw std::runtime_error(std::format(
-            "Unable to open compressed file '{}': {}. error: {}",
-            fname,
-            getArchiveErrorMessage(ar.get()),
-            std::strerror(ret_errno)));
+        throw std::runtime_error(
+            std::format(
+                "Unable to open compressed file '{}': {}. error: {}",
+                fname,
+                getArchiveErrorMessage(ar.get()),
+                std::strerror(ret_errno)));
     }
 
     return readArchiveData(ar.get(), fname);
@@ -231,8 +232,8 @@ bool ArchiveDecompressor::pathMatches(const std::string &path1, const std::strin
     if (path1 == path2)
         return true;
 
-    auto abs1 = fs::weakly_canonical(fs::path("/") / path1);
-    auto abs2 = fs::weakly_canonical(fs::path("/") / path2);
+    const auto abs1 = (fs::path("/") / path1).lexically_normal();
+    const auto abs2 = (fs::path("/") / path2).lexically_normal();
 
     return abs1 == abs2;
 }
@@ -296,11 +297,12 @@ archive *ArchiveDecompressor::openArchive()
     int ret = archive_read_open_filename(ar, m_archiveFname.c_str(), DEFAULT_BLOCK_SIZE);
     if (ret != ARCHIVE_OK) {
         int ret_errno = archive_errno(ar);
-        throw std::runtime_error(std::format(
-            "Unable to open compressed file '{}': {}. error: {}",
-            m_archiveFname,
-            getArchiveErrorMessage(ar),
-            std::strerror(ret_errno)));
+        throw std::runtime_error(
+            std::format(
+                "Unable to open compressed file '{}': {}. error: {}",
+                m_archiveFname,
+                getArchiveErrorMessage(ar),
+                std::strerror(ret_errno)));
     }
 
     return ar;
@@ -516,7 +518,7 @@ std::vector<std::string> ArchiveDecompressor::readContents()
         if (!pathname.empty() && pathname.back() == '/')
             continue;
 
-        contents.push_back(fs::weakly_canonical(fs::path("/") / pathname).string());
+        contents.push_back((fs::path("/") / pathname).lexically_normal().string());
     }
 
     return contents;
@@ -538,7 +540,7 @@ std::generator<ArchiveDecompressor::ArchiveEntry> ArchiveDecompressor::read()
             continue;
 
         ArchiveEntry entry;
-        entry.fname = fs::weakly_canonical(fs::path("/") / pathname).string();
+        entry.fname = (fs::path("/") / pathname).lexically_normal().string();
         auto filetype = archive_entry_filetype(en);
 
         // check if we are dealing with a symlink
