@@ -186,6 +186,14 @@ TEST_CASE("Utils: getTextFileContents and getFileContents read file data", "[uti
     fs::remove(tmpfile);
 }
 
+TEST_CASE("Utils: normalizePath", "[utils]")
+{
+    REQUIRE(normalizePath("/usr") == "/usr");
+    REQUIRE(normalizePath("/usr/") == "/usr");
+    REQUIRE(normalizePath("/usr//") == "/usr");
+    REQUIRE(normalizePath("/usr/test/..//") == "/usr");
+}
+
 TEST_CASE("Selectively reading tarball", "[zarchive]")
 {
     std::string archive = fs::path(getTestSamplesDir()) / "test.tar.xz";
@@ -324,9 +332,11 @@ TEST_CASE("Image size operations", "[utils][imagesize]")
     }
 }
 
-TEST_CASE("HintRegistry functionality", "[hintregistry]")
+TEST_CASE("GeneratorResult functionality", "[result]")
 {
-    using namespace ASGenerator;
+    /**
+     * HINTS REGISTRY
+     */
 
     SECTION("Load hints registry")
     {
@@ -407,14 +417,16 @@ TEST_CASE("HintRegistry functionality", "[hintregistry]")
         // Clean up
         fs::remove(tempFile);
     }
-}
 
-TEST_CASE("GeneratorResult functionality", "[result]")
-{
-    using namespace ASGenerator;
+    /**
+     * GENERATOR RESULT
+     */
 
     auto pkg = std::make_shared<DummyPackage>("foobar", "1.0.0", "amd64");
 
+    // Ensure hints registry is loaded
+    REQUIRE_NOTHROW(loadHintsRegistry());
+
     SECTION("Basic GeneratorResult operations")
     {
         GeneratorResult result(pkg);
@@ -431,9 +443,6 @@ TEST_CASE("GeneratorResult functionality", "[result]")
     {
         GeneratorResult result(pkg);
 
-        // Ensure hints registry is loaded
-        loadHintsRegistry();
-
         // Add a hint with component ID
         std::unordered_map<std::string, std::string> vars = {
             {"icon_fname",      "test.png" },
@@ -456,7 +465,6 @@ TEST_CASE("GeneratorResult functionality", "[result]")
     SECTION("Generate hints JSON")
     {
         GeneratorResult result(pkg);
-        loadHintsRegistry();
 
         // Add some hints
         const std::unordered_map<std::string, std::string> &vars = {
@@ -489,7 +497,6 @@ TEST_CASE("GeneratorResult functionality", "[result]")
     SECTION("Move semantics")
     {
         GeneratorResult result1(pkg);
-        loadHintsRegistry();
         result1.addHint("test.component", "icon-not-found");
 
         // Test move constructor
